@@ -10,7 +10,9 @@ use Raisin::Request;
 use Raisin::Response;
 use Raisin::Routes;
 
-our $VERSION = '0.25';
+use Raisin::Util;
+
+our $VERSION = '0.26';
 
 sub new {
     my ($class, %args) = @_;
@@ -141,7 +143,16 @@ sub psgi {
 
             # Format plugins
             if (ref $data && $self->can('serialize')) {
-                $data = $self->serialize($data);
+                my $accept = $req->header('Accept');
+
+                if (my $serializer = Raisin::Util::detect_serializer($accept)) {
+                    Plack::Util::load_class($serializer);
+                    no strict 'refs';
+                    $data = "${serializer}::serialize"->($data);
+                }
+                else {
+                    $data = $self->serialize($data);
+                }
             }
 
             if (defined $data) {
@@ -602,6 +613,8 @@ Steps 3 and 4 only happen if validation succeeds.
 By default, Raisin supports C<YAML>, C<JSON>, and C<TEXT> content-types.
 The default format is C<TEXT>.
 
+Response format can be determined by Accept header.
+
 Serialization takes place automatically. For example, you do not have to call
 C<encode_json> in each C<JSON> API implementation.
 
@@ -626,10 +639,16 @@ Call C<Data::Dumper-E<gt>Dump> if output data is not a string.
 
 The order for choosing the format is the following.
 
+The order for choosing the format is the following.
+
 =over
 
 =item *
 
+Use the value of ther C<Accept> header.
+
+=item *
+
 Use the C<api_format> if specified.
 
 =item *
