@@ -17,8 +17,8 @@ our @EXPORT = qw(
     before before_validation
     after_validation after
 
-    namespace route_param
-    req res params session
+    namespace route_param params
+    req res param session
     delete get head options patch post put
 );
 
@@ -98,25 +98,45 @@ sub patch   { $app->add_route('PATCH',   namespace(), %SETTINGS, @_) }
 sub post    { $app->add_route('POST',    namespace(), %SETTINGS, @_) }
 sub put     { $app->add_route('PUT',     namespace(), %SETTINGS, @_) }
 
+sub params {
+    my ($params, $method, @other) = @_;
+    my $code = pop @other;
+
+    my @args;
+    if (scalar @other == 1) {
+        push @args, shift @other;
+    }
+    push @args, $code;
+
+    $app->add_route(uc($method), namespace(), %SETTINGS, params => $params, @args);
+}
+
 #
 # Request and Response shortcuts
 #
 sub req { $app->req }
 sub res { $app->res }
-sub params { $app->params(@_) }
+sub param {
+    my $name = shift;
+    return $app->req->parameters->mixed->{$name} if $name;
+    $app->req->parameters->mixed;
+}
 sub session { $app->session(@_) }
 
 #
-#
+# System
 #
 sub plugin { $app->load_plugin(@_) }
+
 sub api_format { $app->api_format(@_) }
 sub api_version { $app->api_version(@_) }
 
-#sub error {
-#    # NOTE render error 500?
-#    $app->res->render_error(@_);
-#}
+#
+# Render
+#
+sub error { $app->res->render_error(@_) }
+
+1;
 
 __END__
 
@@ -129,5 +149,3 @@ Raisin::API - Provides Raisin DSL.
 See L<Raisin>.
 
 =cut
-
-1;
