@@ -7,31 +7,38 @@ no warnings 'redefine';
 
 package Raisin::Types::Integer;
 use base 'Raisin::Types::Base';
-sub regex { qr/^\d+$/ }
+sub constraint {
+    my ($self, $v) = @_;
+    $v =~ /^\d+$/;
+}
 
 # ->
 
 package Raisin::Types::Float;
 use base 'Raisin::Types::Base';
-sub regex { qr/^\d+(?:\.\d+)$/ }
-sub in {
+sub constraint {
     my ($self, $v) = @_;
-    $$v = sprintf '%.4f', $$v;
+    $v =~ /^\d+(?:\.\d+)$/;
+}
+sub coercion {
+    my ($self, $rv) = @_;
+    $$rv = sprintf '%.4f', $$rv;
 }
 
 # ->
 
 package Raisin::Types::String;
-
 use base 'Raisin::Types::Base';
-sub regex { qr/^[\t\r\n\p{IsPrint}]{0,32766}/ }
+sub constraint {
+    my ($self, $v) = @_;
+    $v =~ /^[\t\r\n\p{IsPrint}]{0,32766}/;
+}
 
 # ->
 
 package Raisin::Types::Scalar;
-
 use base 'Raisin::Types::Base';
-sub check {
+sub constraint {
     my ($self, $v) = @_;
     ref \$v eq 'SCALAR';
 }
